searchData={"items":[{"type":"module","title":"SimpleSingletonSupervisor","doc":"It allows you to run a single globally unique process in a cluster. It uses only `:global` and\ndoesn't create any additional processes. Name of the supervisor is determining of the global uniqueness.\n\nBefore starting it synchronizes all nodes via `:global.sync/0` and then runs a transaction to\nguarantee that the only one node is starting this process in the same time. If the process is started\n(or already running) it links that process to the local supervisor. If the process dies it will be\nrestarted on another available node.\n\nIf the process is started on one node and the network is partitioned you would face a situation when\nthe process is running on `n` partitions. When the partition is healed, only one process will be running\nacross the cluster. All other processes will be terminated.\n\nBe aware, in distributed systems you can't guarantee that the process will be started only and only once\nno matter what's happening. You still can face problems like network partitions. You can read more about\nit here: https://keathley.io/blog/sgp.html.\n\nTo start a process you can add `SimpleSingletonSupervisor` to your application's children list:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    singleton_children = [\n      {MyApp.SingletonProcess, []}\n    ]\n\n    children = [\n      {SimpleSingletonSupervisor, [\n        name: MyApp.SingletonSupervisor,\n        strategy: :one_for_one,\n        children: singleton_children\n      ]}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nSingletonSupervisor can also be used as a module-based supervisor:\n\n```elixir\ndefmodule MySingletonSupervisor do\n  @moduledoc false\n\n  use Supervisor\n\n  def start_link(init_arg) do\n    SimpleSingletonSupervisor.start_link(__MODULE__, init_arg, name: __MODULE__)\n  end\n\n  @impl Supervisor\n  def init(_init_arg) do\n    children = [\n      {MyApp.SingletonProcess, []}\n    ]\n\n    Supervisor.init(children, strategy: :one_for_one)\n  end\nend\n```","ref":"SimpleSingletonSupervisor.html"},{"type":"function","title":"SimpleSingletonSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SimpleSingletonSupervisor.html#child_spec/1"},{"type":"function","title":"SimpleSingletonSupervisor.start_link/3","doc":"Starts a module-based singleton supervisor process with the given `module` and `init_arg`.","ref":"SimpleSingletonSupervisor.html#start_link/3"},{"type":"extras","title":"Simple Singleton Supervisor","doc":"# Simple Singleton Supervisor\n\n[![Module Version](https://img.shields.io/hexpm/v/simple_singleton_supervisor.svg)](https://hex.pm/packages/simple_singleton_supervisor)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/simple_singleton_supervisor/)\n[![Total Download](https://img.shields.io/hexpm/dt/simple_singleton_supervisor.svg)](https://hex.pm/packages/simple_singleton_supervisor)\n[![License](https://img.shields.io/hexpm/l/simple_singleton_supervisor.svg)](https://github.com/phyxolog/simple_singleton_supervisor/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/phyxolog/simple_singleton_supervisor.svg)](https://github.com/phyxolog/simple_singleton_supervisor/commits/main)\n\nIt allows you to run a single globally unique process in a cluster. It uses only `:global` and doesn't create any additional processes. Name of the supervisor is determining of the global uniqueness.\n\nYou can find supporting documentation and usage examples [here](https://hexdocs.pm/simple_singleton_supervisor).","ref":"readme.html"},{"type":"extras","title":"Installation - Simple Singleton Supervisor","doc":"Simple Singleton Supervisor is available on Hex, the package can be installed by adding `simple_singleton_supervisor` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_singleton_supervisor, \"~> MAJ.MIN\"}\n  ]\nend\n```\n\nYou can determine the latest version by running `mix hex.info simple_singleton_supervisor` in your shell, or by going to the `simple_singleton_supervisor` [page on hex.pm](https://hex.pm/packages/simple_singleton_supervisor).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Simple Singleton Supervisor","doc":"To start a process you can add `SimpleSingletonSupervisor` to your application's children list:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    singleton_children = [\n      {MyApp.SingletonProcess, []}\n    ]\n\n    children = [\n      {SimpleSingletonSupervisor, [\n        name: MyApp.SingletonSupervisor,\n        strategy: :one_for_one,\n        children: singleton_children\n      ]}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nSingletonSupervisor can also be used as a module-based supervisor:\n\n```elixir\ndefmodule MySingletonSupervisor do\n  @moduledoc false\n\n  use Supervisor\n\n  def start_link(init_arg) do\n    SimpleSingletonSupervisor.start_link(__MODULE__, init_arg, name: __MODULE__)\n  end\n\n  @impl Supervisor\n  def init(_init_arg) do\n    children = [\n      {MyApp.SingletonProcess, []}\n    ]\n\n    Supervisor.init(children, strategy: :one_for_one)\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Simple Singleton Supervisor","doc":"Copyright (c) 2024 Yurii Zhyvaha\n\nThis library is MIT licensed. See the\n[LICENSE.md](https://github.com/phyxolog/simple_singleton_supervisor/blob/master/LICENSE.md) for details.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}